@@ -18,7 +18,7 @@ from .utils import get_annualization_factor, align
 __all__ = [
     'summary',
 
-    'cumulative_returns', 'total_return',
+    'compound_returns', 'drawdown', 'total_return',
     'annual_return', 'annual_volatility',
 
     'mean_return', 'rolling_mean_return',
@@ -105,8 +105,8 @@ def summary(portfolio, benchmark):
     ).round(2)
 
 
-def cumulative_returns(returns):
-    """Calculates Cumulative Returns of portfolio returns.
+def compound_returns(returns):
+    """Calculates Compound Returns of portfolio returns.
 
     Parameters
     ----------
@@ -116,7 +116,7 @@ def cumulative_returns(returns):
     Returns
     -------
     pd.Series
-        Cumulative Returns.
+        Compound Returns.
 
     Notes
     -----
@@ -130,10 +130,10 @@ def drawdown(returns):
     """Calculates Drawdown of portfolio returns.
 
     Drawdown of portfolio is the relative difference between high water mark (cumulative maximum of 
-    the cumulative returns) and cumulative returns:
+    the compound returns) and compound returns:
 
     .. math::
-        DD = -\\frac{High\\;Water\\;Mark - Cumulative\\;Returns}{High\\;Water\\;Mark}
+        DD = -\\frac{High\\;Water\\;Mark - Compounded\\;Returns}{High\\;Water\\;Mark}
 
     Parameters
     ----------
@@ -146,7 +146,7 @@ def drawdown(returns):
         Drawdown.
     """
 
-    equity = cumulative_returns(returns) + 1
+    equity = compound_returns(returns) + 1
     high_water_mark = equity.cummax()
     return -(high_water_mark - equity) / high_water_mark
 
@@ -169,7 +169,7 @@ def total_return(returns):
     Shows additional return, not equity curve's state.
     """
 
-    return cumulative_returns(returns).iloc[-1]
+    return compound_returns(returns).iloc[-1]
 
 
 def annual_return(returns):
@@ -358,7 +358,7 @@ def max_drawdown(returns):
     """Calculates Maximum Drawdown of portfolio returns.
 
     Maximum Drawdown of portfolio is the highest relative difference between high water mark
-    (cumulative maximum of the cumulative returns) and cumulative returns:
+    (cumulative maximum of the compound returns) and compound returns:
 
     .. math::
         MDD = \\max\\{Drawdown\\}
@@ -870,7 +870,7 @@ def rolling_mean_excess_return(returns, benchmark, window=None) -> pd.Series:
 
 
 def alpha(returns, benchmark, risk_free_rate=0):
-    """Calculates Alpha of portfolio returns.
+    """Calculates Annualized Alpha of portfolio returns.
 
     Alpha is the coefficient :math:`\\alpha` in the estimated regression of portfolio `returns` per
     `benchmark` returns (both are adjusted by `risk_free_rate`):
@@ -892,8 +892,8 @@ def alpha(returns, benchmark, risk_free_rate=0):
     float
         Alpha.
     """
-
-    return _alpha_beta(returns, benchmark, risk_free_rate).params.iloc[0]
+    
+    return _alpha_beta(returns, benchmark, risk_free_rate).params[0] * get_annualization_factor(returns)
 
 
 def rolling_alpha(returns, benchmark, risk_free_rate=0, window=None):
@@ -948,7 +948,7 @@ def beta(returns, benchmark, risk_free_rate=0):
         Beta.
     """
 
-    return _alpha_beta(returns, benchmark, risk_free_rate).params.iloc[1]
+    return _alpha_beta(returns, benchmark, risk_free_rate).params[1]
 
 
 def rolling_beta(returns, benchmark, risk_free_rate=0, window=None) -> pd.Series:
@@ -980,7 +980,7 @@ def rolling_beta(returns, benchmark, risk_free_rate=0, window=None) -> pd.Series
 
 
 def _alpha_tstat(returns, benchmark, risk_free_rate=0):
-    return _alpha_beta(returns, benchmark, risk_free_rate).tvalues.iloc[0]
+    return _alpha_beta(returns, benchmark, risk_free_rate).tvalues[0]
 
 
 def _mean_excess_return_tstat(returns, benchmark):
@@ -990,16 +990,16 @@ def _mean_excess_return_tstat(returns, benchmark):
 
 def _adjust_returns(returns, adjustment):
     if isinstance(adjustment, pd.Series):
-        returns, adjustment = align(returns, adjustment)
+        returns, adjustment = returns.align(adjustment, join='inner')
     return returns - adjustment
 
 
 def _alpha_beta(returns, benchmark, risk_free_rate=0):
     adjusted_returns = _adjust_returns(returns, risk_free_rate)
     adjusted_benchmark = _adjust_returns(benchmark, risk_free_rate)
-    adjusted_returns, adjusted_benchmark = align(adjusted_returns, adjusted_benchmark)
-    x = add_constant(adjusted_benchmark)
-    est = OLS(adjusted_returns, x).fit()
+    adjusted_returns, adjusted_benchmark = adjusted_returns.align(adjusted_benchmark, join='inner')
+    x = add_constant(adjusted_benchmark.values)
+    est = OLS(adjusted_returns.values, x).fit()
     return est
 
 
