@@ -13,9 +13,6 @@ going close to relative one with initial balance going to infinity.
 import pandas as pd
 import numpy as np
 
-from .utils import align
-
-
 __all__ = [
     'Portfolio',
     'generate_random_portfolios',
@@ -76,7 +73,7 @@ class Portfolio:
 
         picks = ~stock_prices.isna()
         if mask is not None:
-            picks, mask = align(picks, mask)
+            picks, mask = picks.align(mask, join='inner')
             picks &= mask
         self.picks = picks.astype(int)
 
@@ -165,7 +162,7 @@ class Portfolio:
 
         return self
 
-    def pick_randomly(self, picks, mask=None):
+    def pick_randomly(self, picks, mask=None, rng=np.random.default_rng()):
         """Pick stocks randomly, but in the same quantity as in the `picks`.
 
         In each period collects number of picked stocks and randomly pick the same amount of stocks
@@ -185,20 +182,20 @@ class Portfolio:
             Portfolio with filled picks.
         """
 
-        picks = picks.copy().astype(float)
+        picks = picks.astype(float)
         if mask is not None:
             picks[~mask] = np.nan
 
-        def random_pick(row, indices=np.indices((picks.shape[1],))[0]):
+        def random_pick(row, indices=np.indices((picks.shape[1],))[0], rng=rng):
             random_picks = np.zeros_like(row, dtype=int)
 
             long = (row == 1).sum()
-            long_choice = np.random.choice(indices[~np.isnan(row)], long)
-            random_picks[long_choice] = 1
-
             short = (row == -1).sum()
-            short_choice = np.random.choice(indices[~np.isnan(row) & (random_picks == 0)], short)
-            random_picks[short_choice] = -1
+            total_choice = rng.choice(indices[~np.isnan(row)], long + short, replace=False)
+
+            random_picks[total_choice[:long]] = 1
+            random_picks[total_choice[long:]] = -1
+
             return random_picks
 
         self.picks = pd.DataFrame(
@@ -233,7 +230,7 @@ class Portfolio:
         stock_returns = stock_prices.pct_change().shift(-1)
         if mask is not None:
             stock_returns[~mask] = np.nan
-        stock_returns, picks = align(stock_returns, portfolio.picks)
+        stock_returns, picks = stock_returns.align(portfolio.picks, join='inner')
 
         ideal_picks = pd.DataFrame(np.zeros_like(picks), index=picks.index, columns=picks.columns)
         for date in picks.index:
@@ -252,6 +249,50 @@ class Portfolio:
 
         return self
 
+    def pick_worstly(self, stock_prices, portfolio, mask=None):
+        """Picks stocks worstly in the same quantity as in the `portfolio`.
+
+        In each period simply look forward to stock returns and long stocks with the worst performance and
+        short stocks with the best into an "worst" portfolio.
+
+        Parameters
+        ----------
+        stock_prices : pd.DataFrame
+            Prices, representing stock universe.
+        portfolio : Portfolio
+            Portfolio to be replicated by "worst" portfolio.
+        mask : pd.DataFrame, optional
+            Matrix of True/False, where True means that a stock can be picked in that period and
+            False - that a stock cannot be picked.
+
+        Returns
+        -------
+        Portfolio
+            Portfolio with filled picks.
+        """
+
+        stock_returns = stock_prices.pct_change().shift(-1)
+        if mask is not None:
+            stock_returns[~mask] = np.nan
+        stock_returns, picks = stock_returns.align(portfolio.picks, join='inner')
+
+        worst_picks = pd.DataFrame(np.zeros_like(picks), index=picks.index, columns=picks.columns)
+        for date in picks.index:
+            row = picks.loc[date]
+            returns = stock_returns.loc[date]
+
+            long = (row == 1).sum()
+            short = (row == -1).sum()
+            long_picks = returns.nsmallest(long).index
+            short_picks = returns.nlargest(short).index
+
+            worst_picks.loc[date, long_picks] = 1
+            worst_picks.loc[date, short_picks] = -1
+        
+        self.picks = worst_picks
+
+        return self
+
     def filter(self, mask):
         """Filters `picks` by given `mask`.
 
@@ -269,7 +310,10 @@ class Portfolio:
             Portfolio with transformed picks.
         """
 
-        self.picks, mask = align(self.picks, mask)
+        if isinstance(mask, pd.DataFrame):
+            self.picks, mask = self.picks.align(mask, join='inner')
+        else:
+            self.picks, mask = self.picks.align(mask, join='inner', axis=0)
 
         self.picks[~mask] = 0
 
@@ -284,12 +328,20 @@ class Portfolio:
             Portfolio with filled weights.
         """
 
-        weights = self.picks * np.ones_like(self.picks, dtype=float)
-        long, short = weights == 1, weights == -1
-        weights[long] /= np.nansum(weights[long], axis=1, keepdims=True)
-        weights[short] /= -np.nansum(weights[short], axis=1, keepdims=True)
+        weights = self.picks.values * np.ones_like(self.picks, dtype=float)
 
-        self.weights = weights
+        long, short = weights == 1, weights == -1
+        weights_long = np.where(long, weights, 0)
+        weights_short = np.where(short, weights, 0)
+        
+        with np.errstate(divide='ignore', invalid='ignore'):
+            weights_long /= np.nansum(weights_long, axis=1, keepdims=True)
+            weights_long = np.nan_to_num(weights_long)
+            weights_short /= -np.nansum(weights_short, axis=1, keepdims=True)
+            weights_short = np.nan_to_num(weights_short)
+
+        self.weights = pd.DataFrame(weights_long + weights_short,
+                                    index=self.picks.index, columns=self.picks.columns)
 
         return self
 
@@ -309,14 +361,22 @@ class Portfolio:
             Portfolio with filled weights.
         """
 
-        picks, factor_data = align(self.picks, factor.data)
+        picks, factor_data = self.picks.align(factor.data, join='inner')
 
-        weights = picks * factor_data
-        long, short = weights > 0, weights < 0
-        weights[long] /= np.nansum(weights[long], axis=1, keepdims=True)
-        weights[short] /= -np.nansum(weights[short], axis=1, keepdims=True)
+        weights = (picks.values * factor_data.values).astype(float)
 
-        self.weights = weights.fillna(0)
+        long, short = picks == 1, picks == -1
+        weights_long = np.where(long, weights, 0)
+        weights_short = np.where(short, weights, 0)
+
+        with np.errstate(divide='ignore', invalid='ignore'):
+            weights_long /= np.nansum(weights_long, axis=1, keepdims=True)
+            weights_long = np.nan_to_num(weights_long)
+            weights_short /= -np.nansum(weights_short, axis=1, keepdims=True)
+            weights_short = np.nan_to_num(weights_short)
+
+        self.weights = pd.DataFrame(weights_long + weights_short,
+                                    index=self.picks.index, columns=self.picks.columns)
 
         return self
 
@@ -347,7 +407,7 @@ class Portfolio:
         Works only for factors with all positive values.
         """
 
-        weights, factor_data = align(self.weights, factor.data)
+        weights, factor_data = self.weights.align(factor.data, join='inner', axis=0)
 
         if better == 'more':
             leverage = factor_data / target
@@ -401,15 +461,16 @@ class Portfolio:
         return self
 
     def _allocate_relatively(self, stock_prices, fee_rate):
-        weights, stock_prices = align(self.weights, stock_prices)
+        weights, stock_prices = self.weights.align(stock_prices, join='inner')
         self.positions = weights * (1 - fee_rate)
         universe_returns = stock_prices.pct_change().shift(-1)
-        portfolio_returns = (self.positions * universe_returns).shift().sum(axis=1)
+        portfolio_returns = (self.positions * universe_returns).shift()
 
-        self.returns = portfolio_returns
+        self.returns = pd.Series(np.nansum(portfolio_returns.values, axis=1),
+                                 index=portfolio_returns.index)
 
     def _allocate_with_money(self, stock_prices, balance, fee_rate):
-        weights, stock_prices = align(self.weights, stock_prices)
+        weights, stock_prices = self.weights.align(stock_prices, join='inner')
 
         positions = pd.DataFrame(index=weights.index, columns=weights.columns)
         equity = pd.Series(index=positions.index, dtype=float)
@@ -446,7 +507,7 @@ class Portfolio:
 
 def generate_random_portfolios(stock_prices, portfolio, mask=None, weighting_factor=None,
                                scaling_factor=None, target=1, balance=None, fee_rate=0, n=100,
-                               random_seed=None):
+                               seed=None):
     """Creates `n` random portfolios, replicating portfolio `picks`.
 
     Parameters
@@ -480,7 +541,7 @@ def generate_random_portfolios(stock_prices, portfolio, mask=None, weighting_fac
         Generated random portfolios.
     """
 
-    np.random.seed(random_seed)
+    rng = np.random.default_rng(seed)
 
     picks = portfolio.picks.astype(float)
     picks[stock_prices.isna()] = np.nan
@@ -490,7 +551,7 @@ def generate_random_portfolios(stock_prices, portfolio, mask=None, weighting_fac
     portfolios = []
     for _ in range(n):
         random_portfolio = Portfolio('random')
-        random_portfolio.pick_randomly(picks)
+        random_portfolio.pick_randomly(picks, rng=rng)
         if weighting_factor is not None:
             random_portfolio.weigh_by_factor(weighting_factor)
         else:
